@@ -43,9 +43,6 @@ if __name__ == '__main__':
 
 
 '''
-pack *.py to *.exe
-1. pip install pyinstaller
-2. pyinstaller -F nnff.py  -i myico.ico
-pack to pypi
-python setup.py sdist bdist_wheel
-'''
\ No newline at end of file
+1. python setup.py sdist bdist_wheel
+2. twine upload dist/*
+'''
